package com.fs.store.service;

import com.fs.common.core.domain.R;
import com.fs.statis.dto.ModifyMoreDTO;
import com.fs.store.domain.FsStoreProductScrm;
import com.fs.store.param.FsStoreProductScrmAddEditParam;
import com.fs.store.param.FsStoreProductScrmQueryParam;
import com.fs.store.vo.*;

import java.util.List;
import java.util.Map;

/**
 * 商品Service接口
 *
 * @author fs
 * @date 2022-03-15
 */
public interface IFsStoreProductScrmService
{
    /**
     * 查询商品
     *
     * @param productId 商品ID
     * @return 商品
     */
    public FsStoreProductScrm selectFsStoreProductById(Long productId);

    /**
     * 查询商品列表
     *
     * @param fsStoreProduct 商品
     * @return 商品集合
     */
    public List<FsStoreProductScrm> selectFsStoreProductList(FsStoreProductScrm fsStoreProduct);

    /**
     * 新增商品
     *
     * @param fsStoreProduct 商品
     * @return 结果
     */
    public int insertFsStoreProduct(FsStoreProductScrm fsStoreProduct);

    /**
     * 修改商品
     *
     * @param fsStoreProduct 商品
     * @return 结果
     */
    public int updateFsStoreProduct(FsStoreProductScrm fsStoreProduct);

    /**
     * 批量删除商品
     *
     * @param productIds 需要删除的商品ID
     * @return 结果
     */
    public int deleteFsStoreProductByIds(Long[] productIds);

    /**
     * 删除商品信息
     *
     * @param productId 商品ID
     * @return 结果
     */
    public int deleteFsStoreProductById(Long productId);

    List<FsStoreProductScrmListVO> selectFsStoreProductListVO(FsStoreProductScrm fsStoreProduct);

    List<FsStoreProductScrmListVO> selectFsStoreProductBarCodeListVO(FsStoreProductScrm fsStoreProduct);

    Map<String,Object> getFormatAttr(Long productId, String jsonStr);


    R addOrEdit(FsStoreProductScrmAddEditParam fsStoreProduct);

    List<FsStoreProductScrmListQueryVO> selectFsStoreProductTuiQuery(int count);


    List<FsStoreProductScrmListQueryVO> selectFsStoreProductListQuery(FsStoreProductScrmQueryParam param);

    FsStoreProductScrmQueryVO selectFsStoreProductByIdQuery(Long productId);

    void decProductStock(Long productId, Long productAttrValueId, Integer cartNum);

    void incProductStock(Long num, Long productId, Long productAttrValueId);


    List<FsStoreProductScrmListQueryVO> selectFsStoreProductNewQuery(int count);

    List<FsStoreProductScrmListQueryVO> selectFsStoreProductHotQuery(int count);

    List<FsStoreProductScrmListQueryVO> selectFsStoreProductGoodQuery(int count);

    List<FsStoreProductScrmListQueryVO> selectFsStoreProductTuiListQuery();

    List<FsStoreProductScrmListQueryVO> selectFsStoreProductGoodListQuery();

    Long selectFsStoreProductCount(int type);
    Long selectFsStoreProductCount(int type,Long companyId);

    List<FsStoreProductActivityScrmListVO> selectFsStoreProductByIds(String productIds);

    int updateStock(Long productId);

    List<FsStoreProductScrmExportVO> selectFsStoreProductExportList(FsStoreProductScrm fsStoreProduct);

    String importStoreProduct(List<FsStoreProductScrmExportVO> list, boolean updateSupport);

    void batchModify(ModifyMoreDTO modifyMoreDTO);

}
