package com.fs.store.service.impl;

import com.fs.store.domain.FsStoreOrderItemScrm;
import com.fs.store.mapper.FsStoreOrderItemScrmMapper;
import com.fs.store.param.FsStoreOrderScrmParam;
import com.fs.store.service.IFsStoreOrderItemScrmService;
import com.fs.store.vo.FsStoreOrderItemScrmExportVO;
import com.fs.store.vo.FsStoreOrderItemScrmVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 订单详情Service业务层处理
 *
 * @author fs
 * @date 2022-03-21
 */
@Service
public class FsStoreOrderItemScrmServiceImpl implements IFsStoreOrderItemScrmService
{
    @Autowired
    private FsStoreOrderItemScrmMapper fsStoreOrderItemScrmMapper;

    /**
     * 查询订单详情
     *
     * @param itemId 订单详情ID
     * @return 订单详情
     */
    @Override
    public FsStoreOrderItemScrm selectFsStoreOrderItemById(Long itemId)
    {
        return fsStoreOrderItemScrmMapper.selectFsStoreOrderItemById(itemId);
    }

    /**
     * 查询订单详情列表
     *
     * @param fsStoreOrderItem 订单详情
     * @return 订单详情
     */
    @Override
    public List<FsStoreOrderItemScrm> selectFsStoreOrderItemList(FsStoreOrderItemScrm fsStoreOrderItem)
    {
        return fsStoreOrderItemScrmMapper.selectFsStoreOrderItemList(fsStoreOrderItem);
    }

    /**
     * 新增订单详情
     *
     * @param fsStoreOrderItem 订单详情
     * @return 结果
     */
    @Override
    public int insertFsStoreOrderItem(FsStoreOrderItemScrm fsStoreOrderItem)
    {
        return fsStoreOrderItemScrmMapper.insertFsStoreOrderItem(fsStoreOrderItem);
    }

    /**
     * 修改订单详情
     *
     * @param fsStoreOrderItem 订单详情
     * @return 结果
     */
    @Override
    public int updateFsStoreOrderItem(FsStoreOrderItemScrm fsStoreOrderItem)
    {
        return fsStoreOrderItemScrmMapper.updateFsStoreOrderItem(fsStoreOrderItem);
    }

    /**
     * 批量删除订单详情
     *
     * @param itemIds 需要删除的订单详情ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderItemByIds(Long[] itemIds)
    {
        return fsStoreOrderItemScrmMapper.deleteFsStoreOrderItemByIds(itemIds);
    }

    /**
     * 删除订单详情信息
     *
     * @param itemId 订单详情ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderItemById(Long itemId)
    {
        return fsStoreOrderItemScrmMapper.deleteFsStoreOrderItemById(itemId);
    }

    @Override
    public List<FsStoreOrderItemScrmVO> selectFsStoreOrderItemListByOrderId(Long ordreId) {
        return fsStoreOrderItemScrmMapper.selectFsStoreOrderItemListByOrderId(ordreId);
    }

    @Override
    public List<FsStoreOrderItemScrmExportVO> selectFsStoreOrderItemListExportVO(FsStoreOrderScrmParam fsStoreOrder) {
        return fsStoreOrderItemScrmMapper.selectFsStoreOrderItemListExportVO(fsStoreOrder);
    }

    @Override
    public Long countFsStoreOrderItemListExportVO(FsStoreOrderScrmParam fsStoreOrder) {
        return fsStoreOrderItemScrmMapper.itemsCount(fsStoreOrder);
    }

    @Override
    public int updateFsStoreOrderCode(Long orderId, String orderCode) {
        return fsStoreOrderItemScrmMapper.updateFsStoreOrderCode(orderId,orderCode);
    }
}
