package com.fs.store.service.impl;

import com.fs.store.domain.FsStoreOrderStatusScrm;
import com.fs.store.mapper.FsStoreOrderStatusScrmMapper;
import com.fs.store.service.IFsStoreOrderStatusScrmService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 订单操作记录Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsStoreOrderStatusScrmServiceImpl implements IFsStoreOrderStatusScrmService
{
    @Autowired
    private FsStoreOrderStatusScrmMapper fsStoreOrderStatusMapper;

    /**
     * 查询订单操作记录
     * 
     * @param id 订单操作记录ID
     * @return 订单操作记录
     */
    @Override
    public FsStoreOrderStatusScrm selectFsStoreOrderStatusById(Long id)
    {
        return fsStoreOrderStatusMapper.selectFsStoreOrderStatusById(id);
    }

    /**
     * 查询订单操作记录列表
     * 
     * @param fsStoreOrderStatus 订单操作记录
     * @return 订单操作记录
     */
    @Override
    public List<FsStoreOrderStatusScrm> selectFsStoreOrderStatusList(FsStoreOrderStatusScrm fsStoreOrderStatus)
    {
        return fsStoreOrderStatusMapper.selectFsStoreOrderStatusList(fsStoreOrderStatus);
    }

    /**
     * 新增订单操作记录
     * 
     * @param fsStoreOrderStatus 订单操作记录
     * @return 结果
     */
    @Override
    public int insertFsStoreOrderStatus(FsStoreOrderStatusScrm fsStoreOrderStatus)
    {
        return fsStoreOrderStatusMapper.insertFsStoreOrderStatus(fsStoreOrderStatus);
    }

    /**
     * 修改订单操作记录
     * 
     * @param fsStoreOrderStatus 订单操作记录
     * @return 结果
     */
    @Override
    public int updateFsStoreOrderStatus(FsStoreOrderStatusScrm fsStoreOrderStatus)
    {
        return fsStoreOrderStatusMapper.updateFsStoreOrderStatus(fsStoreOrderStatus);
    }

    /**
     * 批量删除订单操作记录
     * 
     * @param ids 需要删除的订单操作记录ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderStatusByIds(Long[] ids)
    {
        return fsStoreOrderStatusMapper.deleteFsStoreOrderStatusByIds(ids);
    }

    /**
     * 删除订单操作记录信息
     * 
     * @param id 订单操作记录ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderStatusById(Long id)
    {
        return fsStoreOrderStatusMapper.deleteFsStoreOrderStatusById(id);
    }

    @Override
    public int create(Long id, String changetype, String desc) {
        FsStoreOrderStatusScrm storeOrderStatus = new FsStoreOrderStatusScrm();
        storeOrderStatus.setOrderId(id);
        storeOrderStatus.setChangeType(changetype);
        storeOrderStatus.setChangeMessage(desc);
        return fsStoreOrderStatusMapper.insertFsStoreOrderStatus(storeOrderStatus);
    }
}
